@@ -5,6 +5,7 @@ import json
 import logging
 import os.path
 
+from dateutil.parser import isoparse
 import yaml
 
 
@@ -41,6 +42,21 @@ class MustGather:
             self._clusterautoscalers = self.resources('clusterautoscalers', 'autoscaling.openshift.io')
         return self._clusterautoscalers
 
+    @property
+    def clusterversion(self):
+        cv = self.resource_or_none('clusterversions', 'config.openshift.io')
+        if cv is not None:
+            try:
+                hist = cv.get('items')[0].get('status').get('history')
+                hist = sorted(hist, key=lambda h: isoparse(h.get('completionTime')), reverse=True)
+                for h in hist:
+                    if h.get('state') == 'Completed':
+                        return h.get('version')
+            except Exception as ex:
+                logging.error(f'error getting clusterversion {str(ex)}')
+                pass
+        return 'Unknown'
+
     @property
     def machineautoscalers(self):
         if self._machineautoscalers is None:
@@ -78,16 +94,23 @@ class MustGather:
                 # list all files in the pod dir (containers and manifest)
                 for filename in os.listdir(os.path.join(pods_path, podname)):
                     resource = None
+                    currentlog = os.path.join(pods_path, podname, filename, filename, 'logs', 'current.log')
+                    # there should be a manifest for the pod itself
                     if filename == f'{podname}.yaml':
                         logging.debug(f'loading {filename}')
                         with open(os.path.join(pods_path, podname, filename)) as man_file:
-                            resource = yaml.load(man_file.read(), Loader=yaml.FullLoader)
-                    # if this is a container, see if there are logs
-                    elif os.path.exists(os.path.join(pods_path, podname, filename, filename, 'logs')):
-                        for logfile in os.listdir(os.path.join(pods_path, podname, filename, filename, 'logs')):
-                            logging.debug(f'found container logs for {filename}, opening {logfile}')
-                            with open(os.path.join(pods_path, podname, filename, filename, 'logs', logfile)) as log:
-                                containerlogs[logfile] = log.read()
+                            try:
+                                resource = yaml.load(man_file.read(), Loader=yaml.FullLoader)
+                            except yaml.YAMLError as ex:
+                                # if the yaml is bad, log an error and ignore the manifest
+                                mark = ex.problem_mark
+                                logging.error(f'unable to parse {filename}, error at line:{mark.line+1} col:{mark.column+1}')
+                                resource = None
+                    # sub-directories are containers within the pod, check to see if log files exist
+                    elif os.path.exists(currentlog):
+                        logging.debug(f'found container logs for {filename}, opening {currentlog}')
+                        with open(currentlog) as log:
+                            containerlogs[filename] = log.read()
                     else:
                         continue
                     if resource is not None:
@@ -119,7 +142,13 @@ class MustGather:
             return None
         logging.debug(f'loading {group}/{kind} yaml from {man_path}')
         with open(man_path) as man_file:
-            resource = yaml.load(man_file.read(), Loader=yaml.FullLoader)
+            try:
+                resource = yaml.load(man_file.read(), Loader=yaml.FullLoader)
+            except yaml.YAMLError as ex:
+                # if the yaml is bad, log an error and ignore the manifest
+                mark = ex.problem_mark
+                logging.error(f'unable to parse {man_path}, error at line:{mark.line+1} col:{mark.column+1}')
+                return None
             return Resource(resource)
 
     def resources(self, kind, group=None, namespace=None):
